@@ -18,13 +18,13 @@ def Value(value):
     return decorate
 
 
-def get_value(property: str):
-    """
-    从配置中获取key对应的value
-    需要注意有递归的情况
-    :param value:
-    :return:
+def __get_value(property: str):
     """
+        从配置中获取key对应的value
+        需要注意有递归的情况
+        :param value:
+        :return:
+        """
     tup = _do_parse_expression(property)
 
     if tup[0] == "":
@@ -48,6 +48,31 @@ def get_value(property: str):
             return _convertStr2Other(tup[1][1:])
 
 
+def get_value(property: str):
+    """
+    从配置中获取key对应的value
+    需要注意有递归的情况
+    :param value:
+    :return:
+    """
+    # 这里其实还需要根据${}正则的方式,把字符串拆开. 比如: ${sobeycs.redis.host}:${sobeycs.redis.port} 其实应该拆成3个,分别的递归处理.最后再合并
+
+    if not isinstance(property, str):
+        return property
+
+    import re
+    l = re.compile("(\${[\w\.-]+[:[\w]+]*})").split(property)
+
+    l = list(filter(lambda x: x if x is not None and x!="" else "",l))
+
+    if len(l) >1 :
+        return "".join(map(lambda x:str(x),map(__get_value, l)))
+    elif len(l) == 1:
+        return __get_value(l[0])
+    else:
+        return property
+
+
 def _do_parse_expression(value):
     """
     解析表达式
