@@ -46,18 +46,22 @@ class FactDatasourceProxy(object):
         """
 
     @abstractmethod
-    def collect(self, fd_code: str, size: int):
+    def collect(self, fd_code: str, offset: int, size: int, only_model_field: bool):
         """
         返回指定条数的数据
+        :param offset:
+        :param only_model_field:
         :param fd_code:
         :param size: 返回的条数
         :return: list
         """
 
     @abstractmethod
-    def collect_conditions(self, fd_code: str, size: int, condition_groups: list):
+    def collect_conditions(self, fd_code: str, offset: int, size: int, condition_groups: list, only_model_field: bool):
         """
         返回指定查询条件的数据
+        :param offset:
+        :param only_model_field:
         :param fd_code:
         :param size: 返回的条数
         :param condition_groups: 查询条件
@@ -121,7 +125,7 @@ class FactDatasourceProxy(object):
         """
 
     @abstractmethod
-    def delete_conditions(self,fd_code: str,condition_groups:list):
+    def delete_conditions(self, fd_code: str, condition_groups: list):
         """
         根据删除条件,构造删除语句
         :param fd_code:
@@ -180,9 +184,11 @@ class DistributedFactDatasourceProxy(FactDatasourceProxy, Singleton):
         self._inner_check_permission(fd_context, 'read')
         return fd_context.is_empty()
 
-    def collect(self, fd_code: str, size: int):
+    def collect(self, fd_code: str, offset: int, size: int, only_model_field: bool = False):
         """
         返回指定条数的数据
+        :param offset:
+        :param only_model_field:
         :param fd_code:
         :param size: 返回的条数
         :return: list
@@ -191,12 +197,14 @@ class DistributedFactDatasourceProxy(FactDatasourceProxy, Singleton):
         self._inner_check_permission(fd_context, 'read')
         result = fd_context.collect(size)
         # 这里需要对查询结果做字段过滤
-        self._inner_field_permission(fd_context, result)
+        self._inner_field_permission(fd_context, result, only_model_field)
         return result
 
-    def collect_conditions(self, fd_code: str, size: int, condition_groups: list):
+    def collect_conditions(self, fd_code: str, offset: int, size: int, condition_groups: list, only_model_field: bool = False):
         """
         返回指定条数的数据
+        :param offset:
+        :param only_model_field:
         :param fd_code:
         :param size: 返回的条数
         :param condition_groups: 查询条件
@@ -206,7 +214,7 @@ class DistributedFactDatasourceProxy(FactDatasourceProxy, Singleton):
         self._inner_check_permission(fd_context, 'read')
         result = fd_context.collect_conditions(size, condition_groups)
         # 这里需要对查询结果做字段过滤
-        self._inner_field_permission(fd_context, result)
+        self._inner_field_permission(fd_context, result, only_model_field)
         return result
 
     def query(self, fd_code: str, query: str, parameters: dict):
@@ -221,7 +229,7 @@ class DistributedFactDatasourceProxy(FactDatasourceProxy, Singleton):
         self._inner_check_permission(fd_context, 'read')
         result = fd_context.query(query, parameters)
         # 这里需要对查询结果做字段过滤
-        self._inner_field_permission(fd_context,result)
+        self._inner_field_permission(fd_context, result, False)
         return result
 
     def inserts(self, fd_code: str, result_list: list) -> list:
@@ -324,8 +332,8 @@ class DistributedFactDatasourceProxy(FactDatasourceProxy, Singleton):
         # TODO 暂未实现内容权限验证
         return True
 
-    def _inner_field_permission(self, fd_context, result):
-        # TODO 暂未实现内容权限验证
+    def _inner_field_permission(self, fd_context, result, only_model_field):
+        # TODO 暂未实现内容权限验证及只返回模型有的字段
         return True
 
 
@@ -353,7 +361,7 @@ class CentralizedFactDatasourceProxy(FactDatasourceProxy, Singleton):
             if e.response.status_code == 500:
                 # 说明服务器端报错了
                 raise ServiceInnerException(e.response._content.decode('utf-8'))
-            elif e.response.status_code >= 400 and e.response.status_code<500 and e.response.status_code!=404:
+            elif e.response.status_code >= 400 and e.response.status_code < 500 and e.response.status_code != 404:
                 # 说明是认证相关的错误
                 raise AuthException(f"服务端异常 {str(e)} {e.response._content.decode('utf-8')}")
             raise e
@@ -377,7 +385,7 @@ class CentralizedFactDatasourceProxy(FactDatasourceProxy, Singleton):
             if e.response.status_code == 500:
                 # 说明服务器端报错了
                 raise ServiceInnerException(e.response._content.decode('utf-8'))
-            elif e.response.status_code >= 400 and e.response.status_code<500 and e.response.status_code!=404:
+            elif e.response.status_code >= 400 and e.response.status_code < 500 and e.response.status_code != 404:
                 # 说明是认证相关的错误
                 raise AuthException(f"服务端异常 {str(e)} {e.response._content.decode('utf-8')}")
             raise e
@@ -401,21 +409,24 @@ class CentralizedFactDatasourceProxy(FactDatasourceProxy, Singleton):
             if e.response.status_code == 500:
                 # 说明服务器端报错了
                 raise ServiceInnerException(e.response._content.decode('utf-8'))
-            elif e.response.status_code >= 400 and e.response.status_code<500 and e.response.status_code!=404:
+            elif e.response.status_code >= 400 and e.response.status_code < 500 and e.response.status_code != 404:
                 # 说明是认证相关的错误
                 raise AuthException(f"服务端异常 {str(e)} {e.response._content.decode('utf-8')}")
             raise e
 
-    def collect(self, fd_code: str, size: int):
+    def collect(self, fd_code: str, offset: int, size: int, only_model_field: bool = False):
         """
         返回整个数据集
+        :param offset:
+        :param only_model_field:是否只返回模型里面的字段
+        :param size:
         :param fd_code: fd的唯一code
         :return:
         """
         check_instance_avaliable()
 
         try:
-            r = do_service(f"/remote/fd-service/{fd_code}/all")
+            r = do_service(f"/remote/fd-service/{fd_code}/all", params={'offset': offset, 'size': size, 'onlyModelField': only_model_field})
             if r is not None:
                 if isinstance(r, list):
                     return [Munch(x) for x in r]
@@ -427,15 +438,16 @@ class CentralizedFactDatasourceProxy(FactDatasourceProxy, Singleton):
             if e.response.status_code == 500:
                 # 说明服务器端报错了
                 raise ServiceInnerException(e.response._content.decode('utf-8'))
-            elif e.response.status_code >= 400 and e.response.status_code<500 and e.response.status_code!=404:
+            elif e.response.status_code >= 400 and e.response.status_code < 500 and e.response.status_code != 404:
                 # 说明是认证相关的错误
                 raise AuthException(f"服务端异常 {str(e)} {e.response._content.decode('utf-8')}")
             raise e
 
-
-    def collect_conditions(self, fd_code: str, size: int, condition_groups: list):
+    def collect_conditions(self, fd_code: str, offset: int, size: int, condition_groups: list, only_model_field: bool = False):
         """
         返回指定条数的数据
+        :param offset:
+        :param only_model_field:
         :param fd_code:
         :param size: 返回的条数
         :param condition_groups: 查询条件
@@ -444,7 +456,8 @@ class CentralizedFactDatasourceProxy(FactDatasourceProxy, Singleton):
         check_instance_avaliable()
 
         try:
-            r = do_service(f"/remote/fd-service/{fd_code}/conditions", method="post", data=condition_groups, params={'size': size})
+            r = do_service(f"/remote/fd-service/{fd_code}/conditions", method="post", data=condition_groups,
+                           params={'offset': offset, 'size': size, 'onlyModelField': only_model_field})
             if r is not None:
                 if isinstance(r, list):
                     return [Munch(x) for x in r]
@@ -472,7 +485,8 @@ class CentralizedFactDatasourceProxy(FactDatasourceProxy, Singleton):
         check_instance_avaliable()
 
         try:
-            r = do_service(f"/remote/fd-service/{fd_code}/query",method="post",data=parameters,params={'query': query})
+            r = do_service(f"/remote/fd-service/{fd_code}/query", method="post", data=parameters,
+                           params={'query': query})
 
             if r is not None:
                 if isinstance(r, list):
@@ -485,7 +499,7 @@ class CentralizedFactDatasourceProxy(FactDatasourceProxy, Singleton):
             if e.response.status_code == 500:
                 # 说明服务器端报错了
                 raise ServiceInnerException(e.response._content.decode('utf-8'))
-            elif e.response.status_code >= 400 and e.response.status_code<500 and e.response.status_code!=404:
+            elif e.response.status_code >= 400 and e.response.status_code < 500 and e.response.status_code != 404:
                 # 说明是认证相关的错误
                 raise AuthException(f"服务端异常 {str(e)} {e.response._content.decode('utf-8')}")
             raise e
@@ -515,7 +529,7 @@ class CentralizedFactDatasourceProxy(FactDatasourceProxy, Singleton):
                 request.append(result.toDict())
 
         try:
-            r = do_service(f"/remote/fd-service/{fd_code}", method="post", data=request,return_type="json")
+            r = do_service(f"/remote/fd-service/{fd_code}", method="post", data=request, return_type="json")
             if r is not None:
                 if isinstance(r, list):
                     return [Munch(x) for x in r]
@@ -532,7 +546,7 @@ class CentralizedFactDatasourceProxy(FactDatasourceProxy, Singleton):
                 raise AuthException(f"服务端异常 {str(e)} {e.response._content.decode('utf-8')}")
             raise e
 
-    def updates(self, fd_code: str, result_list: list)-> list:
+    def updates(self, fd_code: str, result_list: list) -> list:
         """
         更新数据
         :param fd_code: fd的唯一code
@@ -574,7 +588,6 @@ class CentralizedFactDatasourceProxy(FactDatasourceProxy, Singleton):
                 raise AuthException(f"服务端异常 {str(e)} {e.response._content.decode('utf-8')}")
             raise e
 
-
     def save_or_updates(self, fd_code: str, result_list: list) -> list:
         """
         新增或更新数据
@@ -612,12 +625,11 @@ class CentralizedFactDatasourceProxy(FactDatasourceProxy, Singleton):
             if e.response.status_code == 500:
                 # 说明服务器端报错了
                 raise ServiceInnerException(e.response._content.decode('utf-8'))
-            elif e.response.status_code >= 400 and e.response.status_code<500 and e.response.status_code!=404:
+            elif e.response.status_code >= 400 and e.response.status_code < 500 and e.response.status_code != 404:
                 # 说明是认证相关的错误
                 raise AuthException(f"服务端异常 {str(e)} {e.response._content.decode('utf-8')}")
             raise e
 
-
     def delete_all(self, fd_code: str):
         """
         删除数据集中所有数据
@@ -632,7 +644,7 @@ class CentralizedFactDatasourceProxy(FactDatasourceProxy, Singleton):
             if e.response.status_code == 500:
                 # 说明服务器端报错了
                 raise ServiceInnerException(e.response._content.decode('utf-8'))
-            elif e.response.status_code >= 400 and e.response.status_code<500 and e.response.status_code!=404:
+            elif e.response.status_code >= 400 and e.response.status_code < 500 and e.response.status_code != 404:
                 # 说明是认证相关的错误
                 raise AuthException(f"服务端异常 {str(e)} {e.response._content.decode('utf-8')}")
             raise e
@@ -647,12 +659,13 @@ class CentralizedFactDatasourceProxy(FactDatasourceProxy, Singleton):
         check_instance_avaliable()
 
         try:
-            r = do_service(f"/remote/fd-service/{fd_code}/query", method="delete",params={'query': query}, return_type="None")
+            r = do_service(f"/remote/fd-service/{fd_code}/query", method="delete", params={'query': query},
+                           return_type="None")
         except requests.exceptions.HTTPError as e:
             if e.response.status_code == 500:
                 # 说明服务器端报错了
                 raise ServiceInnerException(e.response._content.decode('utf-8'))
-            elif e.response.status_code >= 400 and e.response.status_code<500 and e.response.status_code!=404:
+            elif e.response.status_code >= 400 and e.response.status_code < 500 and e.response.status_code != 404:
                 # 说明是认证相关的错误
                 raise AuthException(f"服务端异常 {str(e)} {e.response._content.decode('utf-8')}")
             raise e
@@ -712,20 +725,18 @@ class CentralizedFactDatasourceProxy(FactDatasourceProxy, Singleton):
             if e.response.status_code == 500:
                 # 说明服务器端报错了
                 raise ServiceInnerException(e.response._content.decode('utf-8'))
-            elif e.response.status_code >= 400 and e.response.status_code<500 and e.response.status_code!=404:
+            elif e.response.status_code >= 400 and e.response.status_code < 500 and e.response.status_code != 404:
                 # 说明是认证相关的错误
                 raise AuthException(f"服务端异常 {str(e)} {e.response._content.decode('utf-8')}")
             raise e
 
 
-
 @Value("${sobeycube.factdatasource.distributed-mode:False}")
 def distributed_mode():
     pass
 
 
 class FactDatasourceProxyFactory(Singleton):
-
     __instance = None
 
     def get_fd_client_proxy(self, mode: bool = None) -> FactDatasourceProxy:
