@@ -15,6 +15,8 @@ log = logging.getLogger('Ficus')
 
 log.info("=======服务启动开始======")
 app = Flask(__name__)
+# 解决flask中文乱码
+app.config['JSON_AS_ASCII'] = False
 # 设置跨域
 CORS(app, supports_credentials=True)
 
@@ -64,6 +66,7 @@ log.info("服务启动,完成flask框架启动")
 import registry
 
 registry.load_registry_properties(sys.argv[0], "registry.yml")
+registry.load_algorithm_properties(sys.argv[0], "algorithms.yml")
 
 # 加载规则引擎的配置
 from rule_engine import RuleEngineInitialize
@@ -91,9 +94,11 @@ except Exception as e:
 log.info("服务启动,完成处理器的预加载")
 
 # 程序启动后,判断是否需要注册执行器
-from registry.LoadOnRegistryLoader import registry_after_started
+from registry import LoadOnRegistryLoader,LoadOnAlgorithmLoader
+
+LoadOnRegistryLoader.registry_after_started()
+LoadOnAlgorithmLoader.registry_after_started()
 
-registry_after_started()
 
 log.info("服务启动,完成处理器的注册")
 
